# image2heif Utility Tool

image2heif transcodes arbitrary image data into the h265 NV12 format, thereby
making it fit for decoding by NVIDIA's codecs.

image2heif is licensed GPLv2 only because, through FFmpeg, it links to libx265,
which carries the viral GPLv2 license. All other Benzina source code is
licensed MIT.
